/* $Workfile: Dsp54Ioctl.h $   $Revision: 9 $    $Modtime: 8/13/04 4:11p $  */
#ifndef DSP54_IOCTL_H
#define DSP54_IOCTL_H
/*------------------------------------------------------- File Description -*\

  @doc PublicDspSdkApi Dsp54Ioctl

  Odin TeleSystems Inc.

  SAA-1007-1 OTX DSP C54x Software Development Kit (SDK)

  @module

    Dsp54Ioctl.h | Macros and structs for sharing data between a C54x DSP 
    and the host. The following DSPs are supported by this header file: C548/C549, C54CST,
    C5410A, C54V90, C5416. The destinction between each DSP is via CHIP_XXXX
    or similar macros. 

  @index enum struct type | Dsp54Ioctl

  @contents2
  Dsp54Ioctl.h |

\*--------------------------------------------------------------------------*/

#ifdef HDR_DBG // Define to trace include order of headers
#pragma message("\n" __FILE__ "(1): Including\n")
#endif

#if defined(CHIP_5510) 
#pragma message("\nError: This file should not be included for the C5510 DSP\n")
aaaa // To generate a compiler error
#endif

#include "DspIoctl.h"
 
#if defined(__linux__) 
#pragma pack(2)
#elif defined(_TMS320C5XX)
// No pack pragma needed for the DSP compiler
#elif defined(__BORLANDC__)
#pragma option push -a2
#else
#pragma pack(push,2)
#endif


// @type OTXDSP_SDK_TIMESLOTS_PER_HIGHWAY | Otx DSP SDK Number of 64kbit/s timeslots per highway
#define OTXDSP_SDK_TIMESLOTS_PER_HIGHWAY   32
// @type OTXDSP_SDK_WORDSLOTS_PER_HIGHWAY | Otx DSP SDK Number of 128kbit/s timeslots per highway
#define OTXDSP_SDK_WORDSLOTS_PER_HIGHWAY  (OTXDSP_SDK_TIMESLOTS_PER_HIGHWAY/2)


// @type OTXDSP_SDK_EVENT_BUF_LEN | Length of the Circular buffer (in words)
// @type OTXDSP_SDK_EVENT_BUF_PROCESSING_ADDR | The host writes the current processing address to this location
// @type OTXDSP_SDK_EVENT_BUF_ADDR | Start address for Circular buffer of event from the DSP to the host
// @type OTXDSP_SDK_IOCTL_CODE_ADDR | Address to the Io Control Code word
// @type OTXDSP_SDK_IOCTL_HANDLE_ADDR | Address to the handle of the Logical device (nEventSourceId parameter of <f OtxDrvCreateLogicalDevice>)
// @type OTXDSP_SDK_IOCTL_TASKREF_ADDR | Address to the Task Reference value 
// @type OTXDSP_SDK_IOCTL_DATA_ADDR | Address to the start of data
// @type OTXDSP_SDK_IOCTL_DATA_MAX_SIZE | Maximum size of Ioctl data words

// @type OTXDSP_SDK_EVENT_BUF_INCLUDE_HANDLE | Define to one (1) if the DSP code delivers the logical device handle back to the host in the notify event
// @type OTXDSP_SDK_EVENT_BUF_INCLUDE_TASKREF | Define to one (1) if the DSP code delivers the task reference back to the host in the notify event
// @type OTXDSP_SDK_EVENT_BUF_INCLUDE_TIMESTAMP | Define to one (1) if the DSP code delivers a DSP generated timestamp back to the host in the notify event



#if defined(CHIP_54CST) || defined(CHIP_54V90)  
/*--------------------------------------------------------------------------*\

  C54CST and C54V90 DSPs

  On these DSPs the HPI communication buffer can be located anywhere in the
  internal data RAM. We have opted to place the communication buffer at the
  end of the internal data memory of the DSP (0x9800 to 0x9FFF).

\*--------------------------------------------------------------------------*/
#if 1 // 2.0 silicon with 40kword RAM
#define OTXDSP_SDK_HPI_BASE_ADDR   0x9800
#define OTXDSP_SDK_HPI_LENGTH      0x0800
#define OTXDSP_SDK_EVENT_BUF_LEN   0x05F0
#else // 1.0 silicon with 16kword RAM
#define OTXDSP_SDK_HPI_BASE_ADDR   0x3C00
#define OTXDSP_SDK_HPI_LENGTH      0x0400
#define OTXDSP_SDK_EVENT_BUF_LEN   0x01F0
#endif   

// Asynchronous Notification Events from Dsp To Host 
#define OTXDSP_SDK_EVENT_BUF_PROCESSING_ADDR (OTXDSP_SDK_HPI_BASE_ADDR + 0x0002)   
#define OTXDSP_SDK_EVENT_BUF_ADDR            (OTXDSP_SDK_HPI_BASE_ADDR + 0x0003)   

#define OTXDSP_SDK_EVENT_BUF_INCLUDE_HANDLE 1
#define OTXDSP_SDK_EVENT_BUF_INCLUDE_TASKREF 1
//#define OTXDSP_SDK_EVENT_BUF_INCLUDE_TIMESTAMP 1

// IO CONTROL from Host to Dsp
#define OTXDSP_SDK_IOCTL_CODE_ADDR         (OTXDSP_SDK_HPI_BASE_ADDR + OTXDSP_SDK_EVENT_BUF_LEN + 0x0008)   // Start of the DSP IO Control packet. The host will always wait for the DSP to acknowledge the command (by writing <t OTXDSP_SDK_IO_NO_COMMAND> to this address).
#define OTXDSP_SDK_IOCTL_HANDLE_ADDR       (OTXDSP_SDK_IOCTL_CODE_ADDR + 1)   
#define OTXDSP_SDK_IOCTL_TASKREF_ADDR      (OTXDSP_SDK_IOCTL_HANDLE_ADDR + 1)  
#define OTXDSP_SDK_IOCTL_DATA_LEN_ADDR     (OTXDSP_SDK_IOCTL_TASKREF_ADDR + 1) 
#define OTXDSP_SDK_IOCTL_DATA_ADDR         (OTXDSP_SDK_IOCTL_DATA_LEN_ADDR + 1)  
#define OTXDSP_SDK_IOCTL_DATA_MAX_SIZE     ((OTXDSP_SDK_HPI_BASE_ADDR + OTXDSP_SDK_HPI_LENGTH) - OTXDSP_SDK_IOCTL_DATA_ADDR - 1) // Max Data Length (in words)





#elif defined(CHIP_5410A)
/*--------------------------------------------------------------------------*\

  C5410A DSPs

  On these DSPs the HPI communication buffer can be located anywhere in the
  internal data RAM.

  We define a larger notify event buffer compared to the C548/C549 DSPs. The 
  larger buffer has the effect that the interrupt latency requirements on the 
  host are relaxed. Therefore more devices hosted by the DSP code can feed 
  more data to the host without getting into a overrun condition.

\*--------------------------------------------------------------------------*/

#define OTXDSP_SDK_HPI_BASE_ADDR   0x7000
#define OTXDSP_SDK_HPI_LENGTH      0x1000
#define OTXDSP_SDK_EVENT_BUF_LEN  (0x05F0+0x800)  // in words 

// Asynchronous Notification Events from Dsp To Host 
#define OTXDSP_SDK_EVENT_BUF_PROCESSING_ADDR (OTXDSP_SDK_HPI_BASE_ADDR + 0x0002)   
#define OTXDSP_SDK_EVENT_BUF_ADDR            (OTXDSP_SDK_HPI_BASE_ADDR + 0x0003)   

#define OTXDSP_SDK_EVENT_BUF_INCLUDE_HANDLE 1
#define OTXDSP_SDK_EVENT_BUF_INCLUDE_TASKREF 1
//#define OTXDSP_SDK_EVENT_BUF_INCLUDE_TIMESTAMP 1

// IO CONTROL from Host to Dsp
#define OTXDSP_SDK_IOCTL_CODE_ADDR         (OTXDSP_SDK_HPI_BASE_ADDR + OTXDSP_SDK_EVENT_BUF_LEN + 0x0008)   // Start of the DSP IO Control packet. The host will always wait for the DSP to acknowledge the command (by writing <t OTXDSP_SDK_IO_NO_COMMAND> to this address).
#define OTXDSP_SDK_IOCTL_HANDLE_ADDR       (OTXDSP_SDK_IOCTL_CODE_ADDR + 1)   
#define OTXDSP_SDK_IOCTL_TASKREF_ADDR      (OTXDSP_SDK_IOCTL_HANDLE_ADDR + 1)  
#define OTXDSP_SDK_IOCTL_DATA_LEN_ADDR     (OTXDSP_SDK_IOCTL_TASKREF_ADDR + 1) 
#define OTXDSP_SDK_IOCTL_DATA_ADDR         (OTXDSP_SDK_IOCTL_DATA_LEN_ADDR + 1)  
#define OTXDSP_SDK_IOCTL_DATA_MAX_SIZE     ((OTXDSP_SDK_HPI_BASE_ADDR + OTXDSP_SDK_HPI_LENGTH) - OTXDSP_SDK_IOCTL_DATA_ADDR - 1) // Max Data Length (in words)






#elif defined(CHIP_5416)
/*--------------------------------------------------------------------------*\

  C5410A and C5416 DSPs

  On these DSPs the HPI communication buffer can be located anywhere in the
  internal data RAM.

  We define a larger notify event buffer compared to the C548/C549 DSPs. The 
  larger buffer has the effect that the interrupt latency requirements on the 
  host are relaxed. Therefore more devices hosted by the DSP code can feed 
  more data to the host without getting into a overrun condition.

\*--------------------------------------------------------------------------*/
      
#define OTXDSP_SDK_HPI_BASE_ADDR   0x1000
#define OTXDSP_SDK_HPI_LENGTH      0x1000
#define OTXDSP_SDK_EVENT_BUF_LEN  (0x05F0+0x800)  // in words 

// Asynchronous Notification Events from Dsp To Host 
#define OTXDSP_SDK_EVENT_BUF_PROCESSING_ADDR (OTXDSP_SDK_HPI_BASE_ADDR + 0x0002)   
#define OTXDSP_SDK_EVENT_BUF_ADDR            (OTXDSP_SDK_HPI_BASE_ADDR + 0x0003)   

#define OTXDSP_SDK_EVENT_BUF_INCLUDE_HANDLE 1
#define OTXDSP_SDK_EVENT_BUF_INCLUDE_TASKREF 1
//#define OTXDSP_SDK_EVENT_BUF_INCLUDE_TIMESTAMP 1

// IO CONTROL from Host to Dsp
#define OTXDSP_SDK_IOCTL_CODE_ADDR         (OTXDSP_SDK_HPI_BASE_ADDR + OTXDSP_SDK_EVENT_BUF_LEN + 0x0008)   // Start of the DSP IO Control packet. The host will always wait for the DSP to acknowledge the command (by writing <t OTXDSP_SDK_IO_NO_COMMAND> to this address).
#define OTXDSP_SDK_IOCTL_HANDLE_ADDR       (OTXDSP_SDK_IOCTL_CODE_ADDR + 1)   
#define OTXDSP_SDK_IOCTL_TASKREF_ADDR      (OTXDSP_SDK_IOCTL_HANDLE_ADDR + 1)  
#define OTXDSP_SDK_IOCTL_DATA_LEN_ADDR     (OTXDSP_SDK_IOCTL_TASKREF_ADDR + 1) 
#define OTXDSP_SDK_IOCTL_DATA_ADDR         (OTXDSP_SDK_IOCTL_DATA_LEN_ADDR + 1)  
#define OTXDSP_SDK_IOCTL_DATA_MAX_SIZE     ((OTXDSP_SDK_HPI_BASE_ADDR + OTXDSP_SDK_HPI_LENGTH) - OTXDSP_SDK_IOCTL_DATA_ADDR - 1) // Max Data Length (in words)






#elif defined(_TURNSTONE_) && defined(_MOD_HPI_)
/*--------------------------------------------------------------------------*\

  TURNSTONE custom project

  Internal Odin custom configuration.

\*--------------------------------------------------------------------------*/

#define OTXDSP_SDK_HPI_BASE_ADDR 0x1000

// Asynchronous Notification Events from Dsp To Host 
#define OTXDSP_SDK_EVENT_BUF_PROCESSING_ADDR (OTXDSP_SDK_HPI_BASE_ADDR + 0x0002)   
#define OTXDSP_SDK_EVENT_BUF_ADDR            (OTXDSP_SDK_HPI_BASE_ADDR + 0x0003)   
#define OTXDSP_SDK_EVENT_BUF_LEN             0x0320   

#define OTXDSP_SDK_EVENT_BUF_INCLUDE_HANDLE 1
#define OTXDSP_SDK_EVENT_BUF_INCLUDE_TASKREF 1
//#define OTXDSP_SDK_EVENT_BUF_INCLUDE_TIMESTAMP 1

// IO CONTROL from Host to Dsp
#define OTXDSP_SDK_IOCTL_CODE_ADDR         0x1330   // Start of the DSP IO Control packet. The host will always wait for the DSP to acknowledge the command (by writing <t OTXDSP_SDK_IO_NO_COMMAND> to this address).
#define OTXDSP_SDK_IOCTL_HANDLE_ADDR       (OTXDSP_SDK_IOCTL_CODE_ADDR + 1)   
#define OTXDSP_SDK_IOCTL_TASKREF_ADDR      (OTXDSP_SDK_IOCTL_HANDLE_ADDR + 1)  
#define OTXDSP_SDK_IOCTL_DATA_LEN_ADDR     (OTXDSP_SDK_IOCTL_TASKREF_ADDR + 1) 
#define OTXDSP_SDK_IOCTL_DATA_ADDR         (OTXDSP_SDK_IOCTL_DATA_LEN_ADDR + 1)  

#define OTXDSP_HPI_FREE_ADDR_START         0x1500   
#define OTXDSP_DS0_AUDIO_BUFLEN	   	       0x2C0
#define OTXDSP_DS0_AUDIO_BUF_ADDR          (OTXDSP_HPI_FREE_ADDR_START) 

#define OTXDSP_DS0_VISUAL_BUFLEN		       0x30
#define OTXDSP_DS0_VISUAL_BUF_ADDR         (OTXDSP_HPI_FREE_ADDR_START + OTXDSP_DS0_AUDIO_BUFLEN + 1)
 
#define OTXDSP_SDK_IOCTL_DATA_MAX_SIZE     (0x1499 - OTXDSP_SDK_IOCTL_DATA_ADDR - 1) // Max Data Length (in words)

#if defined(_DS0_AUDIO_INPUT_)  && defined(_WAVE_INPUT_)
#define OTX_DSP_DS0_AUDIO_INPUTBUF_ADDR    0x1800
#define OTX_DSP_DS0_AUDIO_INPUTBUF_LEN     0xC8
#endif //_DS0_AUDIO_INPUT_ && _WAVE_INPUT_






#elif defined(OVERRIDDEN_HPI_BUF_CONFIG)  
/*--------------------------------------------------------------------------*\

  Overridden HPI buffer configuration. Special configuration for custom
  configurations. Can be modified to fit the requirment of certain custom
  DSP applications.
  
  See the attributes of the DSP and the DspDemo1.c demo program

\*--------------------------------------------------------------------------*/

#define OTXDSP_SDK_EVENT_BUF_PROCESSING_ADDR 0x100F   
#define OTXDSP_SDK_EVENT_BUF_ADDR            0x1010   
#define OTXDSP_SDK_EVENT_BUF_LEN             0x0200   

//#define OTXDSP_SDK_EVENT_BUF_INCLUDE_HANDLE 1
//#define OTXDSP_SDK_EVENT_BUF_INCLUDE_TASKREF 1
//#define OTXDSP_SDK_EVENT_BUF_INCLUDE_TIMESTAMP 1

#define OTXDSP_SDK_IOCTL_CODE_ADDR         0x1300  
#define OTXDSP_SDK_IOCTL_HANDLE_ADDR       (OTXDSP_SDK_IOCTL_CODE_ADDR + 1)    
#define OTXDSP_SDK_IOCTL_TASKREF_ADDR      (OTXDSP_SDK_IOCTL_HANDLE_ADDR + 1)  
#define OTXDSP_SDK_IOCTL_DATA_LEN_ADDR     (OTXDSP_SDK_IOCTL_TASKREF_ADDR + 1) 
#define OTXDSP_SDK_IOCTL_DATA_ADDR         (OTXDSP_SDK_IOCTL_DATA_LEN_ADDR + 1) 
#define OTXDSP_SDK_IOCTL_DATA_MAX_SIZE     0x200 





#else
/*--------------------------------------------------------------------------*\

  C548/C549

  On this DSP the HPI communication buffer is fixed to area between 0x1000
  and 0x1800. 

\*--------------------------------------------------------------------------*/

#define OTXDSP_SDK_HPI_BASE_ADDR 0x1000

// Asynchronous Notification Events from Dsp To Host 
// The first two addresses of the HPI (0x1000 and 0x1001) are reserved for the OTX DSP Kernel communication
#define OTXDSP_SDK_EVENT_BUF_PROCESSING_ADDR (OTXDSP_SDK_HPI_BASE_ADDR + 0x0002)   
#define OTXDSP_SDK_EVENT_BUF_ADDR            (OTXDSP_SDK_HPI_BASE_ADDR + 0x0003)   
#define OTXDSP_SDK_EVENT_BUF_LEN             0x05F0   

#define OTXDSP_SDK_EVENT_BUF_INCLUDE_HANDLE 1
#define OTXDSP_SDK_EVENT_BUF_INCLUDE_TASKREF 1
//#define OTXDSP_SDK_EVENT_BUF_INCLUDE_TIMESTAMP 1

// IO CONTROL from Host to Dsp
#define OTXDSP_SDK_IOCTL_CODE_ADDR         (OTXDSP_SDK_HPI_BASE_ADDR + 0x05F8)   // Start of the DSP IO Control packet. The host will always wait for the DSP to acknowledge the command (by writing <t OTXDSP_SDK_IO_NO_COMMAND> to this address).
#define OTXDSP_SDK_IOCTL_HANDLE_ADDR       (OTXDSP_SDK_IOCTL_CODE_ADDR + 1)   
#define OTXDSP_SDK_IOCTL_TASKREF_ADDR      (OTXDSP_SDK_IOCTL_HANDLE_ADDR + 1)  
#define OTXDSP_SDK_IOCTL_DATA_LEN_ADDR     (OTXDSP_SDK_IOCTL_TASKREF_ADDR + 1) 
#define OTXDSP_SDK_IOCTL_DATA_ADDR         (OTXDSP_SDK_IOCTL_DATA_LEN_ADDR + 1)  
#define OTXDSP_SDK_IOCTL_DATA_MAX_SIZE     ((OTXDSP_SDK_HPI_BASE_ADDR + 0x0800) - OTXDSP_SDK_IOCTL_DATA_ADDR - 1) // Max Data Length (in words)





#endif // HPI Buffer configuration



#if defined(__linux__) 
#pragma pack(2)
#elif defined(_TMS320C5XX)
// No pack pragma needed for the DSP compiler
#elif defined(__BORLANDC__)
#pragma option pop
#else
#pragma pack(pop)
#endif

/******************************************************************************

  Copyright (C) Odin TeleSystems Inc., 1999-2003


  All rights reserved. No part of this computer program may be reproduced,
  stored in any retrieval system, or transmitted, in any form or by any
  means, electronic, mechanical, photocopying, recording, or otherwise,
  without the prior written permission of Odin TeleSystems Inc., or without
  a permission stipulated in the agreement/contract under which this computer
  program was supplied.

******************************************************************************/
#endif /* DSP54_IOCTL_H */
