/* $Workfile: OsaStd.h $   $Revision: 22 $    $Modtime: 8/27/04 12:54p $  */
#ifndef OSA_STD_H
#define OSA_STD_H
/*******************************************************************************

  @doc PublicHwApi OsaStd

  Copyright (C) 1999-2003 Odin TeleSystems Inc., All Rights Reserved

  OTX Generic Hardware Driver API

  @module
  OsaStd | This file contains prototypes for platform the
  generic implementation of some of the stdio.h, string.h, and ctype.h functions.

  @contents2
  OsaStd.h |

  @index func | OsaStd

  @contents2
  Generic stdio.h Functions - OsaStdXXX() | A platform 
  generic implementation of some of the stdio.h, string.h, 
  and ctype.h, and time.h functions.
  
  @head3 OsaStdXXX() Function Reference |

  @index func | OsaStd

*******************************************************************************/

#include "OsaDef.h"

#if defined(__cplusplus)
extern "C" {
#endif

#ifndef _MAX_PATH
#define _MAX_PATH   255
#endif

struct Osa_tm {
  int tm_sec;     /* seconds after the minute - [0,59] */
  int tm_min;     /* minutes after the hour - [0,59] */
  int tm_hour;    /* hours since midnight - [0,23] */
  int tm_mday;    /* day of the month - [1,31] */
  int tm_mon;     /* months since January - [0,11] */
  int tm_year;    /* years since 1900 */
  int tm_wday;    /* days since Sunday - [0,6] */
  int tm_yday;    /* days since January 1 - [0,365] */
  int tm_isdst;   /* daylight savings time flag */
};

typedef unsigned long     Osa_time_t;

/******************************************************************************

  @func
    Platform generic Osa implementation of the standard localtime() function.

  @comm
    Osa functions are used by the demo programs.

  @xref
    <f OsaConsoleInit>

******************************************************************************/
OTX_EXPORT struct Osa_tm * OTX_API OsaStdLocalTime(
  const Osa_time_t *ptime   // @parm Pointer to time structure
);


/******************************************************************************

  @func
    Get the length of a string.
    Platform generic Osa implementation of the standard strlen() function.

  @comm
    Osa functions are used by the demo programs.

  @xref

******************************************************************************/
OTX_EXPORT int OTX_API OsaStrLen(
  const char *s     // @parm Null-terminated string to get length of.
);

/******************************************************************************

  @func
    Copy a string.
    Platform generic Osa implementation of the standard strcpy() function.

  @comm
    Osa functions are used by the demo programs.

  @xref

******************************************************************************/
OTX_EXPORT void OTX_API OsaStrCpy(
  char *s,    // @parm Destination string
  char *t     // @parm Null-terminated source string
);

/******************************************************************************

  @func
    Copy characters of one string to another.
    Platform generic Osa implementation of the standard strncpy() function.

  @comm
    Osa functions are used by the demo programs.

  @xref

******************************************************************************/
OTX_EXPORT void OTX_API OsaStrNCpy(
  char *s,    // @parm Destination string
  char *t,    // @parm Source string
  int i       // @parm Number of characters to be copied
);

/******************************************************************************

  @func
    Compare strings.
    Platform generic Osa implementation of the standard strcmp() function.

  @comm
    Osa functions are used by the demo programs.

  @xref

******************************************************************************/
OTX_EXPORT int OTX_API OsaStrCmp(
  const char *s,  // @parm Null-terminated string to compare
  const char *t   // @parm Null-terminated string to compare
);

/******************************************************************************

  @func
    Perform a lowercase comparison of strings.
    Platform generic Osa implementation of the standard stricmp() function.

  @comm
    Osa functions are used by the demo programs.

  @xref

******************************************************************************/
OTX_EXPORT int OTX_API OsaStrCmpI(
  const char *s,  // @parm Null-terminated string to compare
  const char *t   // @parm Null-terminated string to compare
);

// support both naming conventions
OTX_EXPORT int OTX_API OsaStrICmp(
  const char *s,  // @parm Null-terminated string to compare
  const char *t   // @parm Null-terminated string to compare
);

/******************************************************************************

  @func
    Convert character to uppercase.
    Platform generic Osa implementation of the standard toupper() function.

  @comm
    Osa functions are used by the demo programs.

  @xref

******************************************************************************/
OTX_EXPORT int OTX_API OsaToUpper(
  const int c   // @parm Character to convert
);

// support previous versions
OTX_EXPORT int OTX_API OsaStdToUpr(
  const int c   // @parm Character to convert
);

/******************************************************************************

  @func
    Convert character to lowercase.
    Platform generic Osa implementation of the standard tolower() function.

  @comm
    Osa functions are used by the demo programs.

  @xref

******************************************************************************/
OTX_EXPORT int OTX_API OsaToLower(
  const int c   // @parm Character to convert
);

/******************************************************************************

  @func
    Convert a string to uppercase.
    Platform generic Osa implementation of the standard strupr() function.

  @comm
    Osa functions are used by the demo programs.

  @xref

******************************************************************************/
OTX_EXPORT char * OTX_API OsaStrUpr(
  char *s            // @parm String to capitalize
);

// support previous versions
OTX_EXPORT char * OTX_API OsaStdStrUpr(
  char *s            // @parm String to capitalize
);

/******************************************************************************

  @func
    Convert string to integer.
    Platform generic Osa implementation of the standard atoi() function.

  @comm
    Osa functions are used by the demo programs.

  @xref

******************************************************************************/
OTX_EXPORT int OTX_API OsaStrToI(
  const char *nptr    // @parm String to be converted
);

/******************************************************************************

  @func
    Initialize characters of a string to a given format.
    Platform generic Osa implementation of the standard strnset() function.

  @comm
    Osa functions are used by the demo programs.

  @xref

******************************************************************************/
OTX_EXPORT char * OTX_API OsaStrnSet(
  char *s,    // @parm String to be altered
  int c,      // @parm Character setting
  int count   // @parm Number of characters to be set
);

/******************************************************************************

  @func
    Scan a string for the last occurrence of a character
    Platform generic Osa implementation of the standard strrchr() function.

  @comm
    Osa functions are used by the demo programs.

  @xref

******************************************************************************/
OTX_EXPORT char * OTX_API OsaStrRChr(
  const char *s,    // @parm Null-terminated string to search
  int c             // @parm Character to be located
);

/******************************************************************************
  OSA std file i/o support
******************************************************************************/
#if defined(OSA_NDIS)
#include "../Lib/OsaDrvLib.h"
long atol(const char *nptr);
typedef struct {
  NDIS_HANDLE     hNdisFile;
  void *          pMappedBuffer;
  OsaInt32        iCurOffset;
  OsaInt32        iFileLength;
} OsaFileHandle, *POsaFileHandle;
#else
typedef void OsaFileHandle, *POsaFileHandle;
#endif

#define OSA_SEEK_SET                    0   // Current position of file pointer
#define OSA_SEEK_CUR                    1   // End of file
#define OSA_SEEK_END                    2   // Beginning of file

/******************************************************************************

  @func
    Open a file.
    Platform generic Osa implementation of the standard fopen() function.

  @comm
    Osa functions are used by the demo programs.

  @xref

******************************************************************************/
OTX_EXPORT POsaFileHandle OTX_API OsaFileOpen(
  const char *pFileName,    // @parm Filename
  const char * mode         // @parm Type of access permitted
);

/******************************************************************************

  @func
    Closes a file 
    Platform generic Osa implementation of the standard fclose() function.

  @comm
    Osa functions are used by the demo programs.

  @xref

******************************************************************************/
OTX_EXPORT void OTX_API OsaFileClose(
  POsaFileHandle hOsaFile   // @parm Pointer to OSA file structure
);

/******************************************************************************

  @func
    Reads data from a file.
    Platform generic Osa implementation of the standard fread() function.

  @comm
    Osa functions are used by the demo programs.

  @xref

******************************************************************************/
OTX_EXPORT OsaInt32 OTX_API OsaFileRead(
  void * buffer,            // @parm Storage location for data
  OsaInt32 size,            // @parm Item size in bytes
  OsaInt32 count,           // @parm Maximum number of items to be read
  POsaFileHandle OsaFile    // @parm Pointer to OSA file structure
);

/******************************************************************************

  @func
    Moves the file pointer to a specified location.
    Platform generic Osa implementation of the standard fseek() function.

  @comm
    Osa functions are used by the demo programs.

  @xref

******************************************************************************/
OTX_EXPORT OsaInt32 OTX_API OsaFileSeek(
  POsaFileHandle OsaFile,     // @parm Pointer to OSA file structure
  OsaInt32 offset,            // @parm Number of bytes from origin
  OsaInt32 origin             // @parm Initial position
);

#if defined(__cplusplus)
}
#endif


/*******************************************************************************

  Copyright (C) Odin TeleSystems Inc., 1999-2003

  All rights reserved. No part of this computer program may be reproduced,
  stored in any retrieval system, or transmitted, in any form or by any
  means, electronic, mechanical, photocopying, recording, or otherwise,
  without the prior written permission of Odin TeleSystems Inc., or without
  a permission stipulated in the agreement/contract under which this computer
  program was supplied.

*******************************************************************************/

#endif // OSA_STD_H
